@@ -1,4 +1,4 @@
-/*	$Id: FaxAcctInfo.h,v 1.4 2004/03/17 18:26:52 lhoward Exp $ */
+/*	$Id: FaxAcctInfo.h,v 1.6 2005/03/05 16:33:33 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -27,6 +27,7 @@
 #define	_FaxAcctInfo_
 
 #include "Types.h"
+#include "CallID.h"
 #include <time.h>
 
 struct FaxAcctInfo {
@@ -43,10 +44,10 @@ struct FaxAcctInfo {
     u_int	npages;		// pages successfully sent/rcvd
     u_int	params;		// encoded transfer parameters
     const char*	status;		// status info (optional)
-    const char*	cidname;	// caller id name
-    const char*	cidnumber;	// caller id number
+    CallID	callid;		// call identification
     const char* owner;		// job owner (uid)
+    fxStr	faxdcs;		// negotiated DCS parameters
 
-    bool record(const char* cmd) const;
+    bool record(const char* cmd);
 };
 #endif /* _FaxAcctInfo_ */
